/**
 * P4
 * http://snarfed.org/space/p4
 *
 * Copyright 2001-2004
 * Ken Ashcraft <kashcraft+p4@gmail.com>,
 * Ryan Barrett <p4@ryanb.org>,
 * Maulik Shah <p4@maulik.net>,
 * Nathan Stoll <nathanstoll+p4@gmail.com>
 *
 * @file p4error.h
 *
 * This header defines the error codes and error strings for P4, as well as the
 * p4_perror and p4_abort functions.
 *
 * TODO: -make a table linking error numbers to string description.
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef _P4_ERROR_H
#define _P4_ERROR_H

#include <string>
#include <sys/types.h>
using namespace std;

/** p4_perror
 *
 * Prints str, then a colon, then a description of the given error code.
 */
void p4_perror(uint error, const string &str);


/** p4_abort
 *
 * Prints a description of theerror code, then exits with return code -1.
 */
void p4_abort(uint error);


/*****************************************************************************
 * ERROR CODES
 *****************************************************************************/
const uint kerr_success               = 0;
const uint kerr_bad_arg               = 1;
const uint kerr_lka_user_not_found    = 2;
const uint kerr_no_connections        = 3;
const uint kerr_not_sent              = 4;
const uint kerr_couldnt_create_socket = 5;
const uint kerr_couldnt_bind_socket   = 6;
const uint kerr_couldnt_listen        = 7;
const uint kerr_couldnt_receive       = 8;
const uint kerr_couldnt_connect       = 9;
const uint kerr_bad_header            = 10;
const uint kerr_bad_sig               = 11;
const uint kerr_connect_failed        = 12;
const uint kerr_unknown_plugin        = 13;
const uint kerr_buffer_too_small      = 14;
const uint kerr_no_msg                = 15;
const uint kerr_select_failed         = 16;
const uint kerr_no_users              = 17;
const uint kerr_boot_init_failed      = 18;
const uint kerr_bad_address           = 19;
const uint kerr_couldnt_add_user      = 20;
const uint kerr_couldnt_get_lka       = 21;
const uint kerr_already_connected     = 22;
const uint kerr_plugin_already_loaded = 23;
const uint kerr_plugin_not_loaded     = 24;

#endif  // _P4_ERROR_H
